#
# spec file for package libzip
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 2

Name:           libzip
Version:        0.11.1
Release:        6.5
Summary:        C library for reading, creating, and modifying zip archives
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Source0:        http://www.nih.at/libzip/%{name}-%{version}.tar.xz
Url:            http://www.nih.at/libzip
BuildRequires:  autoconf >= 2.68
BuildRequires:  libtool
BuildRequires:  pkg-config
# for tests
BuildRequires:  timezone
# for tests
BuildRequires:  unzip
BuildRequires:  xz
BuildRequires:  zlib-devel
Provides:       libzip-util = %{version}
Obsoletes:      libzip-util < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#PATCH-FIX-UPSTREAM: fix a visibility issues in an upstream way
Patch0:         libzip-visibility.diff
#PATCH-FIX-OPENSUSE: close on exec, upstream is aware, will be probably fixes next release
Patch1:         libzip-ocloexec.patch
#PATCH-FIX-OPENSUSE: deprecate old autoconf macros
Patch2:         libzip-autoconf-268.patch
Patch3:         libzip-CVE-2015-2331.patch
Patch4:         libzip-segfault-invalid-zip.patch

%description
libzip is a C library for reading, creating, and modifying zip
archives. Files can be added from data buffers, files, or compressed. This
package contains a set of small utilities built using libzip
 * zipmerge - merge source zip archives into the target one
 * zipcmp - compares the zip archives and check if they contains same files
 * ziptorrent - manipulate with a restricted file format used for using bittorrent on zip files.

%package -n libzip%soname
Summary:        C library for reading, creating, and modifying zip archives
Group:          Development/Libraries/C and C++

%description -n libzip%{soname}
This is libzip, a C library for reading, creating, and modifying zip
archives.  Files can be added from data buffers, files, or compressed
data copied directly from other zip archives.  Changes made without
closing the archive can be reverted.  The API is documented by man
pages.

%package devel
Summary:        C library for reading, creating, and modifying zip archives
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libzip%{soname} = %{version}

%description devel
libzip is a C library for reading, creating, and modifying zip
archives. This package contains devel files.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3
%patch4

%build
autoreconf -fiv
%configure --disable-static --with-pic
make %{?_smp_mflags}

%check
TZ=Europe/Vienna make %{?_smp_mflags} check VERBOSE=1

%install
%{__make} install DESTDIR=%{buildroot}
%__cp lib/zipconf.h %buildroot/%_includedir/zipconf.h
rm -f %{buildroot}%{_libdir}/libzip.la

%post -n libzip%{soname} -p /sbin/ldconfig

%postun -n libzip%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS NEWS README THANKS TODO
%{_bindir}/ziptorrent
%{_bindir}/zipcmp
%{_bindir}/zipmerge
%{_mandir}/man1/*.1*

%files -n libzip%{soname}
%defattr(-,root,root)
%{_libdir}/libzip.so.%{soname}*

%files devel
%defattr(-,root,root)
%{_libdir}/%{name}.so
%{_includedir}/zip.h
%{_includedir}/zipconf.h
%{_libdir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/*.3*

%changelog
* Fri Jan 22 2016 pgajdos@suse.com
- fix segfault when opening invalid zip file [bsc#963071]
  + libzip-segfault-invalid-zip.patch
* Thu Oct  8 2015 pgajdos@suse.com
- add baselibs.conf [bnc#949461]
* Fri Mar 20 2015 pgajdos@suse.com
- fix CVE-2015-2331 [bnc#923240]
  + libzip-CVE-2015-2331.patch
* Mon May  6 2013 mvyskocil@suse.com
- use upstream patch for visibility
  drop: libzip-0.8.hg20080403-visibility.patch
  add : libzip-visibility.diff
- tag all patches according a policy
* Mon Apr 29 2013 mvyskocil@suse.com
- make test failure fatal again and add needed
  timezone and unzip build dependencies
* Mon Apr 29 2013 mvyskocil@suse.com
- update to 0.11.1
  * Fix bugs in zip_set_file_compression().
  * Added Zip64 support (large file support)
  * Added UTF-8 support for file names, file comments, and archive comments
  * Changed API for name and comment related functions for UTF-8 support
  * Added zip_discard()
  * Added ZIP_TRUNCATE for zip_open()
  * Added zip_set_file_compression()
  * Added API for accessing and modifying extra fields
  * Improved API type consistency
  * Use gcc4's visibility __attribute__
  * More changes for Windows support
  * Additional test cases
- split the automake part from ocloexec patch to
  libzip-autoconf-268.patch
- drop already upstream libzip.test.diff
- make tests non-fail, until issue will be solved upstream
* Mon Mar  4 2013 jengelh@inai.de
- Specify exact build requirements on autotools
  (2.68 comes from patch; tarball has 2.57)
* Tue Mar 20 2012 pgajdos@suse.com
- updated to 0.10.1: fixes
  * CVE-2012-1162 [bnc#751829]
  * CVE-2012-1163 [bnc#751830]
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Dec 29 2011 crrodriguez@opensuse.org
- Use O_CLOEXEC where needed, as calling applications
  may fork.. execve and we end up leaking internal fds.
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Jul 25 2011 andrea@opensuse.org
- restore zipconf.h into include dir or packages using zip.h
  will fail to build
* Tue Mar 22 2011 coolo@novell.com
- fix -devel dependency
* Tue Mar 22 2011 mvyskocil@suse.cz
- don't move zipconf.h to include dir
* Mon Mar 21 2011 mvyskocil@suse.cz
- update to 0.10 - rename to libzip to avoid source package rename on
  each soname change. Package libzip deprecate libzip-utils
  * add zip_get_num_files(), deprecate zip_get_num_entries().
  * support for traditional PKWARE encryption added.
  * fix opening archives with more than 65535 entries.
  * fix some memory leaks.
  * fix cmake build and installation
  * fix memory leak in error case in zip_open()
  * fix CVE-2011-0421 (no security implications though) (bnc#681193)
  * more documentation.
- refresh libzip-0.8.hg20080403-visibility.patch
- add libzip.test.diff from upstream fixing failed tests
- add libzip-0.10-zipconf-location.patch installs zipconf.h to includedir
- add pkg-config to BuildRequires
* Sun Jul 27 2008 crrodriguez@suse.de
- update to version 0.9
  * remove erroneous references to GPL
  * add support for torrentzip
  * new functions: zip_get_archive_flag, zip_set_archive_flag
  * zip_source_zip: add flag to force recompression
  * zip_sorce_file: only keep file open while reading from it
* Thu Apr  3 2008 crrodriguez@suse.de
- initial version for openSUSE 11, needed by ARK/KDE4
* Thu Jun  7 2007 judas_iscariote@shorewall.net
- update to stable 0.8 version
